==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/PayDriver_PayPalStd.pm <==
package WebGUI::i18n::Spanish::PayDriver_PayPalStd;
use utf8;
our $I18N = {
  'PayPal' => {
    'lastUpdated' => '1253884090',
    'message' => 'PayPal'
  },
  'button image' => {
    'lastUpdated' => '1253884105',
    'message' => 'URL al Botón PayPal'
  },
  'button image help' => {
    'lastUpdated' => '1253884134',
    'message' => 'Si define esta opción, se usarán las imágenes de PayPal para los botones de pago.'
  },
  'cart transaction mismatch' => {
    'lastUpdated' => '1253884157',
    'message' => 'Se detectó una inconsistencia en el Carrito. Este incidente está siendo registrado en bitácoras.'
  },
  'currency' => {
    'lastUpdated' => '1253884163',
    'message' => 'Moneda'
  },
  'currency help' => {
    'lastUpdated' => '1253884180',
    'message' => 'La moneda a emplear en las transacciones a su Cuenta PayPal.'
  },
  'emailMessage' => {
    'lastUpdated' => '1253889946',
    'message' => 'Mensaje de Correo'
  },
  'emailMessage help' => {
    'lastUpdated' => '1253889995',
    'message' => 'Indique el mensaje personalizado que será agregado al mensaje de correo que PayPal le enviará al usuario.'
  },
  'error occurred message' => {
    'lastUpdated' => '1253890074',
    'message' => 'Ocurrieron los siguientes errores:'
  },
  'extra info' => {
    'lastUpdated' => '1253890594',
    'message' => 'Recuerde modificar su Perfil PayPal de manera tal que en la sección Website Payments, las opciones <em>"Payment Data Transfer"</em> y <em>"Auto Return"</em> estén habilitadas. Así mismo, configure <em>"Return URL"</em> con'
  },
  'identity token' => {
    'lastUpdated' => '1253890608',
    'message' => 'Token de Identidad PDT'
  },
  'identity token help' => {
    'lastUpdated' => '1253890667',
    'message' => 'Ingrese el Identity Token presentado debajo del botón Payment Data Transfer en las preferencias de su perfil PayPal.'
  },
  'invalid address' => {
    'lastUpdated' => '1253890735',
    'message' => 'La dirección ingresada no es válida.'
  },
  'invalid city' => {
    'lastUpdated' => '1253890748',
    'message' => 'La ciudad ingresada no es válida.'
  },
  'invalid email' => {
    'lastUpdated' => '1253890724',
    'message' => 'La dirección de correo ingresada no es válida.'
  },
  'invalid firstName' => {
    'lastUpdated' => '1253890760',
    'message' => 'El nombre ingresado es inválido.'
  },
  'invalid lastName' => {
    'lastUpdated' => '1253890770',
    'message' => 'El apellido indicado es inválido.'
  },
  'invalid zip' => {
    'lastUpdated' => '1253890781',
    'message' => 'La Zona Postal indicada es inválida.'
  },
  'label' => {
    'lastUpdated' => '1253890792',
    'message' => 'PayPal'
  },
  'live url' => {
    'lastUpdated' => '1253890801',
    'message' => 'URL Producción'
  },
  'live url help' => {
    'lastUpdated' => '1253890817',
    'message' => 'El URL al cual enviar las transacciones en modo producción.'
  },
  'module name' => {
    'lastUpdated' => '1253890824',
    'message' => 'PayPal'
  },
  'no description' => {
    'lastUpdated' => '1253890840',
    'message' => 'Sin descripción'
  },
  'password' => {
    'lastUpdated' => '1253890980',
    'message' => 'Contraseña PayPal'
  },
  'password help' => {
    'lastUpdated' => '1253890866',
    'message' => 'Ingrese la contraseña de su cuenta PayPal.'
  },
  'sandbox url' => {
    'lastUpdated' => '1253890875',
    'message' => 'URL Pruebas'
  },
  'sandbox url help' => {
    'lastUpdated' => '1253890892',
    'message' => 'El URL al cual enviar las transacciones en modo pruebas (<em>sandbox</em>)'
  },
  'signature' => {
    'lastUpdated' => '1253890906',
    'message' => 'Firma'
  },
  'signature help' => {
    'lastUpdated' => '1253890920',
    'message' => 'La firma de su cuenta PayPal.'
  },
  'use sandbox' => {
    'lastUpdated' => '1253890930',
    'message' => 'Modo Pruebas'
  },
  'use sandbox help' => {
    'lastUpdated' => '1253890959',
    'message' => 'Indique si desea utilizar el ambiente PayPal Sandbox, recomendado durante el período de pruebas.'
  },
  'vendorId' => {
    'lastUpdated' => '1253890971',
    'message' => 'Cuenta PayPal'
  },
  'vendorId help' => {
    'lastUpdated' => '1253890995',
    'message' => 'Ingrese la dirección de correo que identifica a su cuenta PayPal.'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/PayDriver_PayPalStd.pm <==
package WebGUI::i18n::Spanish::PayDriver_PayPalStd;
use utf8;
our $I18N = {
  'Pay' => {
    'lastUpdated' => '1276813895',
    'message' => 'Pagar'
  },
  'PayPal' => {
    'lastUpdated' => '1253884090',
    'message' => 'PayPal'
  },
  'button image' => {
    'lastUpdated' => '1253884105',
    'message' => 'URL al Botón PayPal'
  },
  'button image help' => {
    'lastUpdated' => '1253884134',
    'message' => 'Si define esta opción, se usarán las imágenes de PayPal para los botones de pago.'
  },
  'cart summary template' => {
    'lastUpdated' => '1276813980',
    'message' => 'Plantilla para Resumen de Carrito -- PayPal Standard'
  },
  'cart transaction mismatch' => {
    'lastUpdated' => '1253884157',
    'message' => 'Se detectó una inconsistencia en el Carrito. Este incidente está siendo registrado en bitácoras.'
  },
  'currency' => {
    'lastUpdated' => '1253884163',
    'message' => 'Moneda'
  },
  'currency help' => {
    'lastUpdated' => '1253884180',
    'message' => 'La moneda a emplear en las transacciones a su Cuenta PayPal.'
  },
  'emailMessage' => {
    'lastUpdated' => '1253889946',
    'message' => 'Mensaje de Correo'
  },
  'emailMessage help' => {
    'lastUpdated' => '1253889995',
    'message' => 'Indique el mensaje personalizado que será agregado al mensaje de correo que PayPal le enviará al usuario.'
  },
  'error occurred message' => {
    'lastUpdated' => '1253890074',
    'message' => 'Ocurrieron los siguientes errores:'
  },
  'extra info' => {
    'lastUpdated' => '1253890594',
    'message' => 'Recuerde modificar su Perfil PayPal de manera tal que en la sección Website Payments, las opciones <em>"Payment Data Transfer"</em> y <em>"Auto Return"</em> estén habilitadas. Así mismo, configure <em>"Return URL"</em> con'
  },
  'identity token' => {
    'lastUpdated' => '1253890608',
    'message' => 'Token de Identidad PDT'
  },
  'identity token help' => {
    'lastUpdated' => '1253890667',
    'message' => 'Ingrese el Identity Token presentado debajo del botón Payment Data Transfer en las preferencias de su perfil PayPal.'
  },
  'invalid address' => {
    'lastUpdated' => '1253890735',
    'message' => 'La dirección ingresada no es válida.'
  },
  'invalid city' => {
    'lastUpdated' => '1253890748',
    'message' => 'La ciudad ingresada no es válida.'
  },
  'invalid email' => {
    'lastUpdated' => '1253890724',
    'message' => 'La dirección de correo ingresada no es válida.'
  },
  'invalid firstName' => {
    'lastUpdated' => '1253890760',
    'message' => 'El nombre ingresado es inválido.'
  },
  'invalid lastName' => {
    'lastUpdated' => '1253890770',
    'message' => 'El apellido indicado es inválido.'
  },
  'invalid zip' => {
    'lastUpdated' => '1253890781',
    'message' => 'La Zona Postal indicada es inválida.'
  },
  'label' => {
    'lastUpdated' => '1253890792',
    'message' => 'PayPal'
  },
  'live url' => {
    'lastUpdated' => '1253890801',
    'message' => 'URL Producción'
  },
  'live url help' => {
    'lastUpdated' => '1253890817',
    'message' => 'El URL al cual enviar las transacciones en modo producción.'
  },
  'module name' => {
    'lastUpdated' => '1253890824',
    'message' => 'PayPal'
  },
  'no description' => {
    'lastUpdated' => '1253890840',
    'message' => 'Sin descripción'
  },
  'password' => {
    'lastUpdated' => '1253890980',
    'message' => 'Contraseña PayPal'
  },
  'password help' => {
    'lastUpdated' => '1253890866',
    'message' => 'Ingrese la contraseña de su cuenta PayPal.'
  },
  'sandbox url' => {
    'lastUpdated' => '1253890875',
    'message' => 'URL Pruebas'
  },
  'sandbox url help' => {
    'lastUpdated' => '1253890892',
    'message' => 'El URL al cual enviar las transacciones en modo pruebas (<em>sandbox</em>)'
  },
  'signature' => {
    'lastUpdated' => '1253890906',
    'message' => 'Firma'
  },
  'signature help' => {
    'lastUpdated' => '1253890920',
    'message' => 'La firma de su cuenta PayPal.'
  },
  'summary template' => {
    'lastUpdated' => '1276813993',
    'message' => 'Plantilla para Resumen de Carrito'
  },
  'summary template help' => {
    'lastUpdated' => '1276814029',
    'message' => 'Indique la plantilla a emplear para desplegar el resumen del carrito de compras para que el usuario confirme el pago.'
  },
  'use sandbox' => {
    'lastUpdated' => '1253890930',
    'message' => 'Modo Pruebas'
  },
  'use sandbox help' => {
    'lastUpdated' => '1253890959',
    'message' => 'Indique si desea utilizar el ambiente PayPal Sandbox, recomendado durante el período de pruebas.'
  },
  'vendorId' => {
    'lastUpdated' => '1253890971',
    'message' => 'Cuenta PayPal'
  },
  'vendorId help' => {
    'lastUpdated' => '1253890995',
    'message' => 'Ingrese la dirección de correo que identifica a su cuenta PayPal.'
  }
}
;

1;
